@@ -27,6 +27,8 @@ describe 'heat::api' do
       it { is_expected.to contain_heat_config('heat_api/bind_port').with_value( params[:bind_port] ) }
       it { is_expected.to contain_heat_config('heat_api/workers').with_value( params[:workers] ) }
 
+      it { is_expected.to contain_heat_config('heat_api/cert_file').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('heat_api/key_file').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with SSL socket options set' do
@@ -81,32 +83,8 @@ describe 'heat::api' do
           :enabled        => false })
       end
 
-      it 'configures heat-api service' do
-
-        is_expected.to contain_service('heat-api').with(
-          :ensure     => nil,
-          :name       => platform_params[:api_service_name],
-          :enable     => false,
-          :hasstatus  => true,
-          :hasrestart => true,
-          :tag        => 'heat-service',
-        )
-        is_expected.to contain_service('heat-api').that_subscribes_to(nil)
-      end
-    end
-
-    context 'with $sync_db set to false in ::heat' do
-      let :pre_condition do
-        "class { 'heat::keystone::authtoken':
-           password => 'a_big_secret',
-         }
-         class {'heat':
-           sync_db => false,
-         }"
-      end
-
-      it 'configures heat-api service to not subscribe to the dbsync resource' do
-        is_expected.to contain_service('heat-api').that_subscribes_to(nil)
+      it 'does not configure heat-api service' do
+        is_expected.to_not contain_service('heat-api')
       end
     end
   end
