@@ -10,7 +10,7 @@ describe 'heat::wsgi::apache_api_cfn' do
         :servername                  => facts[:fqdn],
         :bind_host                   => nil,
         :path                        => '/',
-        :ssl                         => true,
+        :ssl                         => false,
         :workers                     => facts[:os_workers],
         :ssl_cert                    => nil,
         :ssl_key                     => nil,
@@ -19,14 +19,20 @@ describe 'heat::wsgi::apache_api_cfn' do
         :ssl_crl_path                => nil,
         :ssl_certs_dir               => nil,
         :wsgi_process_display_name   => nil,
+        :vhost_custom_fragment       => nil,
         :threads                     => 1,
         :priority                    => 10,
+        :headers                     => nil,
+        :request_headers             => ['set Content-Type "application/json"'],
         :custom_wsgi_process_options => {},
-        :access_log_file             => false,
-        :access_log_format           => false,
-        :vhost_custom_fragment       => nil,
-        :request_headers             => ['set Content-Type "application/json"'],)
-      }
+        :access_log_file             => nil,
+        :access_log_pipe             => nil,
+        :access_log_syslog           => nil,
+        :access_log_format           => nil,
+        :error_log_file              => nil,
+        :error_log_pipe              => nil,
+        :error_log_syslog            => nil,
+      )}
     end
   end
 
