@@ -10,7 +10,7 @@ describe 'heat::wsgi::apache_api' do
         :servername                  => facts[:fqdn],
         :bind_host                   => nil,
         :path                        => '/',
-        :ssl                         => true,
+        :ssl                         => false,
         :workers                     => facts[:os_workers],
         :ssl_cert                    => nil,
         :ssl_key                     => nil,
@@ -22,10 +22,17 @@ describe 'heat::wsgi::apache_api' do
         :vhost_custom_fragment       => nil,
         :threads                     => 1,
         :priority                    => 10,
+        :headers                     => nil,
+        :request_headers             => nil,
         :custom_wsgi_process_options => {},
-        :access_log_file             => false,
-        :access_log_format           => false,)
-      }
+        :access_log_file             => nil,
+        :access_log_pipe             => nil,
+        :access_log_syslog           => nil,
+        :access_log_format           => nil,
+        :error_log_file              => nil,
+        :error_log_pipe              => nil,
+        :error_log_syslog            => nil,
+      )}
     end
   end
 
