@@ -21,12 +21,13 @@ describe 'heat::wsgi::apache' do
           'bind_port'                   => '8000',
           'group'                       => 'heat',
           'user'                        => 'heat',
-          'ssl'                         => 'true',
+          'ssl'                         => false,
           'wsgi_daemon_process'         => "heat_#{title}",
           'wsgi_process_group'          => "heat_#{title}",
           'wsgi_script_dir'             => platform_params[:wsgi_script_dir],
           'wsgi_script_file'            => "heat_#{title}",
           'allow_encoded_slashes'       => 'on',
+          'headers'                     => nil,
           'request_headers'             => nil,
         )}
       end
